@@ -12,7 +12,7 @@ use Perinci::Sub::Util qw(gen_modified_sub);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-08-20'; # DATE
 our $DIST = 'App-wordlist'; # DIST
-our $VERSION = '0.287'; # VERSION
+our $VERSION = '0.288'; # VERSION
 
 our %SPEC;
 
@@ -927,7 +927,13 @@ _
         $_[0]{examples} = [
             {
                 argv => ['wt_S_'],
-                summary => 'W* T* _ S _ (W & T incorrect position, S correct)',
+                summary => 'One guess (lowercase means incorrect position)',
+                test => 0,
+                'x.doc.show_result' => 0,
+            },
+            {
+                argv => ['___s_', '_o___', '___ht', '_L___'],
+                summary => 'For guesses (lowercase means incorrect position)',
                 test => 0,
                 'x.doc.show_result' => 0,
             },
@@ -937,28 +943,28 @@ _
         my %args = @_;
 
         $args{arg} //= [];
-        return [400, "I only accept one arg"] if @{ $args{arg} } > 1;
 
-        if (@{ $args{arg} }) {
-            return [400, "Please specify a 5-letter pattern"] if @{ $args{arg} } > 1;
+        my $chars_unordered = '';
+        my @new_arg;
+        for my $arg (@{ $args{arg} }) {
             my $re = '';
-            my $chars_unordered = '';
-            for my $char (split //, $args{arg}[0]) {
+            for my $char (split //, $arg) {
                 if ($char eq '_') {
                     $re .= '.';
                 } elsif ($char eq uc($char)) {
-                    $re .= quotemeta($char);
+                    $re .= quotemeta(lc $char);
                 } else {
-                    $re .= '.';
-                    $chars_unordered .= $char;
+                    $re .= "[^".quotemeta($char)."]";
+                    $chars_unordered .= $char unless index($chars_unordered, $char) >= 0;
                 }
             }
             $re = "/\\A$re\\z/";
-            $args{arg} = [$re];
-
-            $args{chars_unordered} = $chars_unordered if length $chars_unordered;
+            push @new_arg, $re;
         }
 
+        $args{arg} = \@new_arg;
+        $args{chars_unordered} = $chars_unordered if length $chars_unordered;
+
         log_trace "Arguments passed to wordlist(): %s", \%args;
         wordlist(%args);
     },
@@ -979,7 +985,7 @@ App::wordlist - Grep words from (or test them against) WordList::*
 
 =head1 VERSION
 
-This document describes version 0.287 of App::wordlist (from Perl distribution App-wordlist), released on 2022-08-20.
+This document describes version 0.288 of App::wordlist (from Perl distribution App-wordlist), released on 2022-08-20.
 
 =head1 SYNOPSIS
 
@@ -1240,10 +1246,14 @@ Examples:
 
 =over
 
-=item * W* T* _ S _ (W & T incorrect position, S correct):
+=item * One guess (lowercase means incorrect position):
 
  wordlist_wordle(arg => ["wt_S_"]);
 
+=item * For guesses (lowercase means incorrect position):
+
+ wordlist_wordle(arg => ["___s_", "_o___", "___ht", "_L___"]);
+
 =back
 
 This is a wrapper to L<wordlist> designed to be a convenient helper to solve
